/**
 * Copyright (c) 2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api;

import org.ow2.petals.jmx.api.api.exception.ComponentErrorException;
import org.ow2.petals.jmx.api.api.exception.IllegalComponentStateException;

/**
 * Interface of a JMX component associated to a JBI component.
 * 
 * @author Christophe Deneux - Linagora
 */
public interface ComponentClient {

    /**
     * Component states
     */
    // TODO: To share with the Petals kernel side
    public enum State {

        STARTED("Started"), STOPPED("Stopped"), SHUTDOWN("Shutdown"), UNKNOWN("Unknown");

        private final String label;

        private State(final String label) {
            this.label = label;
        }

        public final static State parse(final String label) throws IllegalComponentStateException {
            for (final State state : State.values()) {
                if (state.label.equals(label)) {
                    return state;
                }
            }
            // No existing state matches the value
            throw new IllegalComponentStateException(label);
        }

        public final String toString() {
            return this.label;
        }

    }

    /**
     * Start the component associated to this JMX component.
     * 
     * @throws ComponentErrorException
     */
    public void start() throws ComponentErrorException;

    /**
     * Stop the component associated to this JMX component.
     * 
     * @throws ComponentErrorException
     */
    public void stop() throws ComponentErrorException;

    /**
     * Shutdown the component associated to this JMX component.
     * 
     * @throws ComponentErrorException
     */
    public void shutdown() throws ComponentErrorException;

    /**
     * Get the current state of the JBI component associated to this JMX
     * component.
     * 
     * @return the current state of the JBI component.
     * @throws ComponentErrorException
     */
    public State getCurrentState() throws ComponentErrorException;

}
