/**
 * Copyright (c) 2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api;

import java.util.Map;
import java.util.Properties;
import java.util.Set;

import org.ow2.petals.jmx.api.api.exception.PetalsAdminServiceErrorException;

/**
 * Interface of the JMX Petals Administration service.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface PetalsAdminServiceClient {

    /**
     * Name of the associated MBean
     */
    public static final String PETALS_ADMIN_MBEAN_NAME = "PetalsAdmin";
    
    /**
     * Stop the PEtALS container.
     * 
     * @see PetalsAdminInterface#stopContainer()
     * @throws PerformActionErrorException
     */
    public void stopContainer() throws PetalsAdminServiceErrorException;

    /**
     * Shut down the PEtALS container.
     * 
     * @see PetalsAdminInterface#shutdownContainer()
     * @throws PerformActionErrorException
     */
    public void shutdownContainer() throws PetalsAdminServiceErrorException;

    /**
     * Retrieve the Petals topology.
     * 
     * @param securityPassPhrase
     * @return
     * @throws PetalsAdminServiceErrorException
     */
    public Set<Map<String, String>> retrieveTopology(final String securityPassPhrase)
            throws PetalsAdminServiceErrorException;
    
    /**
     * Retrieve the properties (content of $PETALS_HOME/conf/server.properties)
     * of the server on which your are connected.
     * 
     * @return The server properties
     * @throws PetalsAdminServiceErrorException
     */
    public Properties retrieveServerProperties() throws PetalsAdminServiceErrorException;

    /**
     * Ping the container on which the JMX connection is established.
     * 
     * @return <code>true</code> if "ping" succeeds.
     * @throws PetalsAdminServiceErrorException
     */
    public boolean ping() throws PetalsAdminServiceErrorException;
}
